<?php

/**
 * @file
 * Smartling context authorize.
 */

/**
 * Smartling context authorize.
 *
 * @return array
 *   Return response array.
 */
function smartling_translation_context_authorize($username) {
  global $user;

  $auth = new SmartlingContextAuthorize($user);
  return $auth->authorize($username);
}

/**
 * SmartlingContextAuthorize.
 */
class SmartlingContextAuthorize {
  protected $user;

  protected static $authError = array(
    'response' => array(
      'data' => NULL,
      'code' => "AUTHENTICATION_ERROR",
      "messages" => array("Bad credentials"),
    ),
  );
  protected static $validationError = array(
    'response' => array(
      'data' => NULL,
      'code' => "AUTHENTICATION_ERROR",
      "messages" => array("Bad credentials"),
    ),
  );

  /**
   * Construct.
   *
   * @param object $user
   *   User object.
   */
  public function __construct($user) {
    $this->user = $user;
  }

  /**
   * Authorize.
   *
   * @param string $name
   *   Name.
   *
   * @return array
   *   Return response array.
   */
  public function authorize($name) {
    $cookie = $this->authByName($name);
    if (!$cookie) {
      return self::$authError;
    }


    return array(
      'response' => array(
        'data' => array('cookie' => $cookie),
        'code' => "SUCCESS",
        "messages" => array(),
      ),
    );
  }

  /**
   * Auth by name.
   *
   * @param string $name
   *   Name.
   *
   * @return int|string
   *   Return result.
   */
  protected function authByName($name) {
    //$user = $this->user;
    global $user;

    if ($user->uid) {
      module_invoke_all('user_logout', $user);
    }
    if (isset($name) && $account = user_load_by_name($name)) {
      $old_uid = $user->uid;
      $user = $account;
      $user->timestamp = time() - 9999;
      if (!$old_uid) {
        // Switch from anonymous to authorized.
        drupal_session_regenerate();
      }
      $edit = array();
      user_module_invoke('login', $edit, $user);
      drupal_session_commit();
      //die(session_name() . "=" . session_id());
      return session_name() . "=" . session_id();
    }
    return 0;
  }
}
